==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/SecretStoreDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs.builder
import com.pulumi.azurenative.migrate.kotlin.enums.SecretStoreType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property secretStore
 * @property secretStoreProperties
 */
public data class SecretStoreDetailsArgs(
    public val secretStore: Output<Either<String, SecretStoreType>>? = null,
    public val secretStoreProperties: Output<SecretStorePropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs =
        com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs.builder()
            .secretStore(
                secretStore?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .secretStoreProperties(
                secretStoreProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [SecretStoreDetailsArgs].
 */
@PulumiTagMarker
public class SecretStoreDetailsArgsBuilder internal constructor() {
    private var secretStore: Output<Either<String, SecretStoreType>>? = null

    private var secretStoreProperties: Output<SecretStorePropertiesArgs>? = null

    /**
     * @param value
     */
    @JvmName("moaymgdtlrdpmqbq")
    public suspend fun secretStore(`value`: Output<Either<String, SecretStoreType>>) {
        this.secretStore = value
    }

    /**
     * @param value
     */
    @JvmName("xquamdinjeffmovv")
    public suspend fun secretStoreProperties(`value`: Output<SecretStorePropertiesArgs>) {
        this.secretStoreProperties = value
    }

    /**
     * @param value
     */
    @JvmName("dfppanjoxmyhmctf")
    public suspend fun secretStore(`value`: Either<String, SecretStoreType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStore = mapped
    }

    /**
     * @param value
     */
    @JvmName("pttpwmfyslodejgp")
    public fun secretStore(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SecretStoreType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretStore = mapped
    }

    /**
     * @param value
     */
    @JvmName("dnlrublmeusglgye")
    public fun secretStore(`value`: SecretStoreType) {
        val toBeMapped = Either.ofRight<String, SecretStoreType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretStore = mapped
    }

    /**
     * @param value
     */
    @JvmName("nrcykqbakwfflwwf")
    public suspend fun secretStoreProperties(`value`: SecretStorePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStoreProperties = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kvxorimxvpsaxtkj")
    public suspend
    fun secretStoreProperties(argument: suspend SecretStorePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = SecretStorePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.secretStoreProperties = mapped
    }

    internal fun build(): SecretStoreDetailsArgs = SecretStoreDetailsArgs(
        secretStore = secretStore,
        secretStoreProperties = secretStoreProperties,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/SecretStoreDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs.builder
import com.pulumi.azurenative.migrate.kotlin.enums.SecretStoreType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property secretStore
 * @property secretStoreProperties
 */
public data class SecretStoreDetailsArgs(
    public val secretStore: Output<Either<String, SecretStoreType>>? = null,
    public val secretStoreProperties: Output<SecretStorePropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs =
        com.pulumi.azurenative.migrate.inputs.SecretStoreDetailsArgs.builder()
            .secretStore(
                secretStore?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .secretStoreProperties(
                secretStoreProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [SecretStoreDetailsArgs].
 */
@PulumiTagMarker
public class SecretStoreDetailsArgsBuilder internal constructor() {
    private var secretStore: Output<Either<String, SecretStoreType>>? = null

    private var secretStoreProperties: Output<SecretStorePropertiesArgs>? = null

    /**
     * @param value
     */
    @JvmName("qawwskjrnvcmwemt")
    public suspend fun secretStore(`value`: Output<Either<String, SecretStoreType>>) {
        this.secretStore = value
    }

    /**
     * @param value
     */
    @JvmName("ywuffoynttaobrjl")
    public suspend fun secretStoreProperties(`value`: Output<SecretStorePropertiesArgs>) {
        this.secretStoreProperties = value
    }

    /**
     * @param value
     */
    @JvmName("rnfmsofnlusmdrno")
    public suspend fun secretStore(`value`: Either<String, SecretStoreType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStore = mapped
    }

    /**
     * @param value
     */
    @JvmName("wbjhdljyamtcnnsb")
    public fun secretStore(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SecretStoreType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretStore = mapped
    }

    /**
     * @param value
     */
    @JvmName("wtrbbfwucqbjokpa")
    public fun secretStore(`value`: SecretStoreType) {
        val toBeMapped = Either.ofRight<String, SecretStoreType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretStore = mapped
    }

    /**
     * @param value
     */
    @JvmName("xhtuxhoyefqswcgt")
    public suspend fun secretStoreProperties(`value`: SecretStorePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStoreProperties = mapped
    }

    /**
     * @param argument
     */
    @JvmName("mrrbsqplwpnbxnri")
    public suspend
    fun secretStoreProperties(argument: suspend SecretStorePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = SecretStorePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.secretStoreProperties = mapped
    }

    internal fun build(): SecretStoreDetailsArgs = SecretStoreDetailsArgs(
        secretStore = secretStore,
        secretStoreProperties = secretStoreProperties,
    )
}
